pub enum SqlExprToken {
SelfAlias,
OtherAlias,
AuxParam(String),
UnresolvedArg,
Literal(String),
Arg(SqlArg),
Alias(String),
Predicate {
columns: Vec<PredicateColumn>,
args: Vec<SqlArg>,
},
}Expand description
Token that makes up SqlExpr. The expression is a string of tokens. To turn the expression into SQL, each
Variants
SelfAlias
Self alias in expression
OtherAlias
Other alias in expression
AuxParam(String)
Aux param in expression
UnresolvedArg
Unresolved arguent in expression
Literal(String)
Literal raw SQL in expression
Arg(SqlArg)
Argument in expression
Alias(String)
Canonical alias in expression
Predicate
Predicate in expression A predicate token has been introduced to improve SQL formatting. Depending on the number of columns and arguments this translates different SQL.